@@ -43,21 +43,30 @@ class Synchronizer:
         if not self.regions_all or not self.municipalities_all or not self.districs_all or not self.sites:
             self.__prepare_all_regions()
 
+        # municipalities sets on sites - site.address exists
         municipalities_on_sites = [[site.address.municipalityName,
                                     site.address.districtName] for site in self.sites if site.address]
         self.municipalities_assigned = [muni for muni in self.municipalities_all if [
             muni.name, muni.districtName] in municipalities_on_sites]
 
+        # get districts from step aboce
         districts_on_assigned_municipalities = set(
             municipality.districtName for municipality in self.municipalities_assigned)
         self.districts_assigned = [
             dis for dis in self.districs_all if dis.name in districts_on_assigned_municipalities]
 
+        # get regions from step above
         regions_on_assigned_districts = set(
             district.regionName for district in self.districts_assigned)
         self.regions_assigned = [
             reg for reg in self.regions_all if reg.name in regions_on_assigned_districts]
 
+        # get sites where address from ruian does not exists
+        #   but region is assigned - foreign regions for example
+        sites_without_address_with_region = [[site.regionId, site.regionName] for site in self.sites if not site.address and site.regionId]
+        # get regions from sites without address and append them
+        self.regions_assigned.extend([reg for reg in self.regions_all if [reg.id, reg.name] in sites_without_address_with_region])
+
     def sync_regions(self):
         if not self.regions_assigned or not self.municipalities_assigned or not self.districts_assigned or not self.sites:
             self.__prepare_assigned_regions()
