@@ -23,9 +23,9 @@ class NbSite(NetboxBase):
         self.physical_address = komora_obj.address.text if komora_obj.address else ""
         self.shipping_address = ""
         self.latitude = float(
-            komora_obj.latitude) if komora_obj.latitude else None
-        self.longitude = float(
-            komora_obj.longitude) if komora_obj.longitude else None
+            komora_obj.latitude[0:9]) if komora_obj.latitude else None
+        self.longitude = round(float(
+            komora_obj.longitude[0:10]),6) if komora_obj.longitude else None
 
         self.komora_id = komora_obj.id
         self.komora_url = f"{get_config()['komora']['KOMORA_URL']}/app/site/{self.komora_id}"
@@ -47,6 +47,8 @@ class NbSite(NetboxBase):
                 if municipality_komora_id:
                     self.region = self.netbox.connection.dcim.regions.get(
                         cf_komora_id=municipality_komora_id)
+            elif komora_obj.regionId:
+                self.region = self.netbox.connection.dcim.regions.get(cf_komora_id=komora_obj.regionId)
         except Exception as e:
             logger.exception(
                 f"Unable to find region {komora_obj.address} for site {self.name}")
